package cz.kebrt.unitcheck.api.data;

/**
 * Describes a choice generator. Choice generators are used for traversing
 * various execution paths in the state graph. The generator is created when some Java
 * instruction is reached. It generates a set of choices (values), each one starts a new
 * transition in the state graph.
 */
public class ChoiceGeneratorHolder {

    private final String type;
    private final String info;
    private final int currentChoice;
    private final int totalChoices;
    private final String instruction;

    /**
     * Constructs an instance.
     *
     * @param type type of the generator
     * @param info additional information about the generator
     * @param currentChoice number of the current choice
     * @param totalChoices total number of choices produced by the generator
     * @param instruction instruction that caused the generator to be created
     */
    public ChoiceGeneratorHolder(String type, String info, int currentChoice,
            int totalChoices, String instruction) {
        super();
        this.type = type;
        this.info = info;
        this.currentChoice = currentChoice;
        this.totalChoices = totalChoices;
        this.instruction = instruction;
    }

    /**
     * Returns type of the generator.
     *
     * @return type of the generator
     */
    public String getType() {
        return type;
    }

    /**
     * Returns additional information about the generator.
     *
     * @return additional information about the generator
     */
    public String getInfo() {
        return info;
    }

    /**
     * Returns number of the current choice.
     *
     * @return number of the current choice
     */
    public int getCurrentChoice() {
        return currentChoice;
    }

    /**
     * Returns total number of choices produced by the generator.
     *
     * @return total number of choices produced by the generator
     */
    public int getTotalChoices() {
        return totalChoices;
    }

    /**
     * Returns instruction that caused the generator to be created.
     *
     * @return instruction that caused the generator to be created
     */
    public String getInstruction() {
        return instruction;
    }

}
