package cz.kebrt.unitcheck.junit;

import cz.kebrt.unitcheck.api.data.Description;
import cz.kebrt.unitcheck.api.data.ExceptionFailure;
import cz.kebrt.unitcheck.junit.holder.TestRunResult;

/**
 * A dual interface to JUnit <code>RunListener</code>. The interface is needed
 * because not all the classes provided by the original interface as arguments
 * cannot be reconstructed in the Java layer (e.g. <code>Result</code> does not
 * have a public constructor). Therefore, custom dual classes from
 * {@link cz.kebrt.unitcheck.api.data} are provided in this listener. Moreover,
 * failures are accompanied with information provided by JPF (e.g. error traces).
 * <p>
 * See the JUnit documentation for more information about <code>RunListener</code>.
 */
public interface TestRunListener {

	public void testRunStarted(Description description);

	public void testRunFinished(TestRunResult result);

	public void testStarted(Description description);

	public void testFinished(Description description);

	public void testFailure(ExceptionFailure f);

	public void testAssumptionFailure(ExceptionFailure f);

	public void testIgnored(Description description);

}
